import { Context } from '../context';
import { DocumentWithId } from '../base/common';
/**
 * Retrieve a top-level document by its `_id` field.
 *
 * @param context the context object
 * @param collectionName name of the collection to search
 * @param id the `_id` value of the root document
 * @param options the the set of options for the search
 * @param options.consistentRead search with strongly consistent reads
 * @returns the stored value, or `undefined` if not found
 * @throws {CollectionNotFoundException} when the collection is not found in the context
 */
export declare function findById<DocumentType extends DocumentWithId>(context: Context, collectionName: string, id: string, options?: {
    consistentRead?: boolean;
}): Promise<DocumentType | undefined>;
